==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/hiddendataspy_001/HiddenDataspy.java <==

package net.datastream.schemas.mp_entities.hiddendataspy_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDDEN"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid",
    "ewsdataspyid",
    "hidden"
})
@XmlRootElement(name = "HiddenDataspy")
public class HiddenDataspy {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "EWSDATASPYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected long ewsdataspyid;
    @XmlElement(name = "HIDDEN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String hidden;

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété ewsdataspyid.
     * 
     */
    public long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Définit la valeur de la propriété ewsdataspyid.
     * 
     */
    public void setEWSDATASPYID(long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Obtient la valeur de la propriété hidden.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDDEN() {
        return hidden;
    }

    /**
     * Définit la valeur de la propriété hidden.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDDEN(String value) {
        this.hidden = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/hiddendataspy_001/HiddenDataspy.java <==

package net.datastream.schemas.mp_entities.hiddendataspy_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDDEN"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid",
    "ewsdataspyid",
    "hidden"
})
@XmlRootElement(name = "HiddenDataspy")
public class HiddenDataspy {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "EWSDATASPYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected long ewsdataspyid;
    @XmlElement(name = "HIDDEN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String hidden;

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the ewsdataspyid property.
     * 
     */
    public long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Sets the value of the ewsdataspyid property.
     * 
     */
    public void setEWSDATASPYID(long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Gets the value of the hidden property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDDEN() {
        return hidden;
    }

    /**
     * Sets the value of the hidden property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDDEN(String value) {
        this.hidden = value;
    }

}
